@@ -28,15 +28,16 @@
 #include "colorschemeinterface.h"
 #include "optionsdialog.h"
 
-#include <QDir>
+#include <QtWidgets/QWidget>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QStatusBar>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QFileDialog>
+#include <QtWidgets/QMenuBar>
+#include <QtWidgets/QMenu>
+#include <QtPrintSupport/QPrintDialog>
 #include <QPainter>
-#include <QStatusBar>
-#include <QInputDialog>
-#include <QFileDialog>
-#include <QMessageBox>
-#include <QMenuBar>
-#include <QMenu>
-#include <QPrintDialog>
+#include <QDir>
 
 
 // ###### Constructor #######################################################
@@ -95,7 +96,7 @@ FractalGeneratorApp::FractalGeneratorApp(QWidget* parent, const QString& fileNam
       fractalAlgorithmGroup->addAction(item);
       item->setData(fractalAlgorithmID);
       item->setCheckable(true);
-      item->setChecked((fractalAlgorithmID == 0));
+      item->setChecked((fractalAlgorithm == View->getAlgorithm()));
       FractalAlgorithmActionList.append(item);
       fractalAlgorithmID++;
    }
@@ -113,7 +114,7 @@ FractalGeneratorApp::FractalGeneratorApp(QWidget* parent, const QString& fileNam
       colorSchemeGroup->addAction(item);
       item->setData(colorSchemeID);
       item->setCheckable(true);
-      item->setChecked((colorSchemeID == 0));
+      item->setChecked((colorScheme == View->getColorScheme()));
       ColorSchemeActionList.append(item);
       colorSchemeID++;
    }
